==> mksc-0.0.1.tar.gz: mksc-0.0.1/src/errormessage.c <==
#include "mk.h"


// compile error.
const MK_CHAR *compileErrorMessage[] = 
{
/* 0 */ 	"There is no error. ", 

/* 1 */ 	"$1 is unidentified. ", 
/* 2 */ 	"$1 is unidentified. $2 is necessary. ", 
/* 3 */ 	"$2 was found after $1. $3 is necessary. ", 

/* 4 */ 	"$1 ($2) is already defined in $3. ", 

/* 5 */ 	"Succession relations of $1(class) are unjust. ", 
/* 6 */ 	"SuperClass $2 of $1 is undefined. ", 

/* 7 */ 	"$2 corresponding to $1 is not found. ", 

/* 8 */ 	"$2 is not found in the terminal of $1. ", 

/* 9 */ 	"An error occurred at the time of the compilation of the definition of $1 ($2). ", 
/*10 */ 	"An error occurred at the time of a compilation of the substance of $1 ($2). ", 
/*11 */ 	"An error occurred during analysis of $1. ", 

/*12 */ 	"I found $2 in the middle of $1. ", 

/*13 */ 	"A ceremony after the $1 operator is unjust. ", 
/*14 */ 	"A ceremony before the $1 operator is unjust. ", 

/*15 */ 	"Argument name $1 repeats. ", 

/*16 */ 	"$2 was found in the terminal of $1. ", 

/*17 */ 	"A format of $1 is unjust. ", 
/*18 */ 	"$2 to continue after $1 is dirty. ", 

/*19 */     "An error occurred during analysis of $1. The token following after that is $2, $3. ", 

/*20 */ 	"A mark was added to token $1 except the numerical value. ", 

/*21 */ 	"Unidentified letter $1 was found. ", 

/*22 */ 	"$1 : No such file. ", 

/*23 */ 	"There is internal error[$1:$2]. ",
};

#if 0
// compile error.
const MK_CHAR *compileErrorMessage[] = 
{
/*  0 */	"error͂܂B",

/*  1 */	"$1͕słB",
/*  2 */	"$1͕słB$2KvłB",
/*  3 */	"$1̌$2܂B$3KvłB",

/*  4 */	"$1($2)$3Ŋɒ`Ă܂B",

/*  5 */	"$1(class)̌p֌WsłB",
/*  6 */	"$1̊NX$2͖`łB",

/*  7 */	"$1ɑΉ$2܂B",

/*  8 */	"$1̏I[$2܂B",

/*  9 */	"$1($2)̒`̃RpCɃG[܂B",
/* 10 */	"$1($2)̎̂̃RpCɃG[܂B",
/* 11 */	"$1̉͒ɃG[܂B",

/* 12 */	"$1̓r$2܂B",

/* 13 */	"$1Zq̌̎słB",
/* 14 */	"$1Zq̑O̎słB",

/* 15 */	"$1dĂ܂B",

/* 16 */	"$1̏I[$2܂B",

/* 17 */	"$1̏słB",
/* 18 */	"$1̌ɑ$2słB",

/* 19 */    "$1̉͒ɃG[܂Bȍ~ɑg[N$2, $3łB",

/* 20 */	"lȊÕg[N$1ɕt܂B",

/* 21 */	"sȕ $1 ܂B",

/* 22 */	"$1I[vł܂B",

/* 23 */	"G[ł $1($2)B",

};
#endif

const MK_CHAR *linkErrorMessage[] = 
{
	"",
};

// vm error
const MK_CHAR *vmErrorMessage[] =
{
/* 0 */ 	"There is not error. ", 

/* 1 */ 	"Variable $1 is not defined in $2. ", 
/* 2 */ 	"Method $1 is not defined in $2. ", 
/* 3 */ 	"Class $1 is not defined. ", 
/* 4 */ 	"A while block corresponding to $1 is not found. ", 
/* 5 */ 	"There are too many arguments handed to method $1. ", 
/* 6 */ 	"I cannot access $1 symbol $2. ", 
/* 7 */ 	"I cannot access $1 method $2. ", 

/* 8 */ 	"It is internal error. A stack position was renewed in a $1 method. ", 
/* 9 */ 	"It is internal error. Unsupported type [$2:$1] was called. ", 
/*10 */ 	"The operand that I cannot use as a member was incorporated. ", 
/*11 */ 	"The nest of the method / block structure call is too deep. ",
/*12 */		"No super class defined in class $1.",
};

#if 0
// vm error
const MK_CHAR *vmErrorMessage[] =
{
/*  0 */	"error͂܂B",

/*  1 */	"ϐ$1$2Œ`Ă܂B",
/*  2 */	"\bh$1$2Œ`Ă܂B",
/*  3 */	"NX$1͒`Ă܂B",
/*  4 */	"$1ɑΉwhileubN܂B",
/*  5 */	"\bh$1ɓnꂽ܂B",
/*  6 */	"$1V{$2ɃANZX邱Ƃ͂ł܂B",
/*  7 */	"$1\bh$2ɃANZX邱Ƃ͂ł܂B",

/*  8 */	"G[łB$1\bhŃX^bNʒu܂B",
/*  9 */	"G[łBT|[gĂȂ^$1($2)Ăяo܂B",
/* 10 */	"oƂĎgpłȂIyhgݍ܂܂B",
/* 11 */	"\bh/ubN\ĂяõlXg[܂B",
/* 12 */	"NX$1̃X[p[NX͒`Ă܂B",
};
#endif

const MK_CHAR *compileWarningMessage[] = 
{
	"",
};

const MK_CHAR *linkWarningMessage[] = 
{
	"",
};

// vm error
const MK_CHAR *vmWarningMessage[] =
{
	"",
};

==> mksc-0.0.4.tar.gz: mksc-0.0.4/src/errormessage.c <==
#include "mk.h"


// compile error.
const MK_CHAR *compileErrorMessage[] = 
{
/* 0 */ 	"There is no error. ", 

/* 1 */ 	"$1 is unidentified. ", 
/* 2 */ 	"$1 is unidentified. $2 is necessary. ", 
/* 3 */ 	"$2 was found after $1. $3 is necessary. ", 

/* 4 */ 	"$1 ($2) is already defined in $3. ", 

/* 5 */ 	"Succession relations of $1(class) are unjust. ", 
/* 6 */ 	"SuperClass $2 of $1 is undefined. ", 

/* 7 */ 	"$2 corresponding to $1 is not found. ", 

/* 8 */ 	"$2 is not found in the terminal of $1. ", 

/* 9 */ 	"An error occurred at the time of the compilation of the definition of $1 ($2). ", 
/*10 */ 	"An error occurred at the time of a compilation of the substance of $1 ($2). ", 
/*11 */ 	"An error occurred during analysis of $1. ", 

/*12 */ 	"I found $2 in the middle of $1. ", 

/*13 */ 	"A ceremony after the $1 operator is unjust. ", 
/*14 */ 	"A ceremony before the $1 operator is unjust. ", 

/*15 */ 	"Argument name $1 repeats. ", 

/*16 */ 	"$2 was found in the terminal of $1. ", 

/*17 */ 	"A format of $1 is unjust. ", 
/*18 */ 	"$2 to continue after $1 is dirty. ", 

/*19 */     "An error occurred during analysis of $1. The token following after that is $2, $3. ", 

/*20 */ 	"A mark was added to token $1 except the numerical value. ", 

/*21 */ 	"Unidentified letter $1 was found. ", 

/*22 */ 	"$1 : No such file. ", 

/*23 */ 	"There is internal error[$1:$2]. ",
};

#if 0
// compile error.
const MK_CHAR *compileErrorMessage[] = 
{
/*  0 */	"error͂܂B",

/*  1 */	"$1͕słB",
/*  2 */	"$1͕słB$2KvłB",
/*  3 */	"$1̌$2܂B$3KvłB",

/*  4 */	"$1($2)$3Ŋɒ`Ă܂B",

/*  5 */	"$1(class)̌p֌WsłB",
/*  6 */	"$1̊NX$2͖`łB",

/*  7 */	"$1ɑΉ$2܂B",

/*  8 */	"$1̏I[$2܂B",

/*  9 */	"$1($2)̒`̃RpCɃG[܂B",
/* 10 */	"$1($2)̎̂̃RpCɃG[܂B",
/* 11 */	"$1̉͒ɃG[܂B",

/* 12 */	"$1̓r$2܂B",

/* 13 */	"$1Zq̌̎słB",
/* 14 */	"$1Zq̑O̎słB",

/* 15 */	"$1dĂ܂B",

/* 16 */	"$1̏I[$2܂B",

/* 17 */	"$1̏słB",
/* 18 */	"$1̌ɑ$2słB",

/* 19 */    "$1̉͒ɃG[܂Bȍ~ɑg[N$2, $3łB",

/* 20 */	"lȊÕg[N$1ɕt܂B",

/* 21 */	"sȕ $1 ܂B",

/* 22 */	"$1I[vł܂B",

/* 23 */	"G[ł $1($2)B",

};
#endif

const MK_CHAR *linkErrorMessage[] = 
{
	"",
};

// vm error
const MK_CHAR *vmErrorMessage[] =
{
/* 0 */ 	"There is no error. ", 

/* 1 */ 	"Symbol $1 is not defined in $2. ", 
/* 2 */ 	"Class $1 is not defined. ", 
/* 3 */ 	"The \"while\" or \"do...while\" block corresponding to $1 is not found. ", 
/* 4 */ 	"There are too many arguments handed to method $1. ", 
/* 5 */ 	"cannot access $1 symbol $2. ", 

/* 6 */ 	"It is internal error. A stack position was renewed in a $1 method. ", 
/* 7 */ 	"It is internal error. Unsupported type [$2:$1] was called. ", 
/* 8 */ 	"The operand that I cannot use as a member was incorporated. ", 
/* 9 */ 	"The nest of the method / block structure call is too deep. ",
/*10 */     "Can not be assigned to the object with final type.",

/*11 */		"It is internal error. The class definition as needed is not found.",

/*12 */		"$1 can not be called for objects that are specified in the left side.",

/*13 */		"Undefined exception.",

/*14 */		"The type of $1 mismatch."
};

#if 0
// vm error
const MK_CHAR *vmErrorMessage[] =
{
/*  0 */	"error͂܂B",

/*  1 */	"V{$1$2Œ`Ă܂B",
/*  2 */	"NX$1͒`Ă܂B",
/*  3 */	"$1ɑΉwhile/do..whileubN܂B",
/*  4 */	"\bh$1ɓnꂽ܂B",
/*  5 */	"$1V{$2ɃANZX邱Ƃ͂ł܂B",

/*  6 */	"G[łB$1\bhŃX^bNʒu܂B",
/*  7 */	"G[łBT|[gĂȂ^$1($2)Ăяo܂B",

/*  8 */	"oƂĎgpłȂIyhgݍ܂܂B",
/*  9 */	"\bh/ubN\ĂяõlXg[܂B",
/* 10 */	"finalCꂽIuWFNgւ̑͂ł܂B",

/* 11 */	"G[łBKvȓNX܂B",

/* 12 */	"ӂŎw肳ꂽIuWFNgɑ΂A$1ĂяoƂ͂ł܂B"
/* 13 */	"`̗O܂B",

/* 14 */	"$1̌^v܂",
};
#endif

const MK_CHAR *compileWarningMessage[] = 
{
	"",
};

const MK_CHAR *linkWarningMessage[] = 
{
	"",
};

// vm error
const MK_CHAR *vmWarningMessage[] =
{
	"",
};
